aboutsummaryrefslogtreecommitdiff
path: root/src/property/package.lisp
diff options
context:
space:
mode:
authorSean Whitton <spwhitton@spwhitton.name>2022-04-03 09:34:37 -0700
committerSean Whitton <spwhitton@spwhitton.name>2022-04-04 14:47:02 -0700
commit006d3969bad1f84c0133a36ed9a623b59bd01c0e (patch)
treeb16c80a6b3d9930dc98f3e3d141a8dabd075b05d /src/property/package.lisp
parent6195f10ed2c7c8999b2fd8078a12c6c84cb5a592 (diff)
downloadconsfigurator-006d3969bad1f84c0133a36ed9a623b59bd01c0e.tar.gz
rename basic propapp accessors
Signed-off-by: Sean Whitton <spwhitton@spwhitton.name>
Diffstat (limited to 'src/property/package.lisp')
-rw-r--r--src/property/package.lisp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/property/package.lisp b/src/property/package.lisp
index 4548056..c4bb24c 100644
--- a/src/property/package.lisp
+++ b/src/property/package.lisp
@@ -38,11 +38,11 @@ Implementations should not fail just because we are not root, or otherwise
privileged, if the package is already installed."))
(defmethod %installed ((package-manager (eql :apt)) packages)
- ;; Call PROPAPPAPPLY directly because we want the :CHECK subroutine run, but
- ;; it does not make sense to run the :HOSTATTRS subroutine because *HOST*
- ;; does not necessarily correspond to the host we're attempting to install
- ;; packages on.
- (propappapply `(apt:installed ,@packages)))
+ ;; Call APPLY-PROPAPP directly because we want the :CHECK subroutine run,
+ ;; but it does not make sense to run the :HOSTATTRS subroutine because
+ ;; *HOST* does not necessarily correspond to the host we're attempting to
+ ;; install packages on.
+ (apply-propapp `(apt:installed ,@packages)))
(define-simple-error package-manager-not-found (aborted-change))